@@ -1,11 +1,11 @@
+import math
+import copy
+
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
 import torch.distributions as D
 
-import math
-import copy
-
 
 def create_masks(input_size: int,
                  hidden_size: int,
@@ -14,7 +14,9 @@ def create_masks(input_size: int,
                  input_degrees: torch.Tensor = None):
     """
     Helper function to create masks.
-    TODO add description.
+    The masks are used to hide certain connections
+    in the neural network thus preserving the 
+    autoregressive property.
     
     Parameters
     ----------
@@ -40,7 +42,7 @@ def create_masks(input_size: int,
     # degrees of connections between layers -- ensure at most in_degree - 1 connections
     degrees = []
 
-    # set input degrees to what is provided in args (the flipped order of the previous layer in a stack of mades);
+    # set input degrees to what is provided in args (the flipped order of the previous layer in a stack of MADEs);
     # else init input degrees based on strategy in input_order (sequential or random)
     if input_order == 'sequential':
         degrees += [torch.arange(input_size)] if input_degrees is None else [input_degrees]
@@ -68,8 +70,7 @@ def create_masks(input_size: int,
 
 class MaskedLinear(nn.Linear):
     """
-    MADE building block layer
-    TODO add description.
+    Masked Linear Layer (MADE building block layer)
 
     Parameters
     ----------
@@ -280,8 +281,7 @@ class FlowSequential(nn.Sequential):
 
 
 class MADE(nn.Module):
-    r"""
-    Masked Autoregressive Density Estimator (MADE)
+    r"""Masked Autoregressive Density Estimator (MADE)
 
     Parameters
     ----------
@@ -294,8 +294,10 @@ class MADE(nn.Module):
     activation : str
         Activation function: ``"relu"`` (default) or ``"tanh"``.
     input_order : str
-        Variable order for creating the autoregressive masks: ``"sequential"`` (default) or ``"random"``.
+        Variable order for creating the autoregressive masks:
+        ``"sequential"`` (default) or ``"random"``.
     """
+
     def __init__(self,
                  input_size: int,
                  hidden_size: int,
@@ -367,15 +369,19 @@ class MADE(nn.Module):
     def inverse(self,
                 u: torch.Tensor,
                 y: torch.Tensor = None,
-                sum_log_abs_det_jacobians=None):  # TODO add sum_log_abs_det_jacobians to docstring
-        """
-        Inverse transformation.
+                sum_log_abs_det_jacobians=None):
+        """Inverse transformation.
+        
         Parameters
         ----------
         u : torch.Tensor
             Input data.
         y : torch.Tensor
             Conditional input data.
+        sum_log_abs_det_jacobians : torch.Tensor
+            Sum of the natural logarithm of the jacobian
+            determinant of the transformation.
+
         Returns
         -------
         Transformed data.
@@ -444,20 +450,26 @@ class MAF(nn.Module):
                  batch_norm: bool = True,
                  **kwargs):
         """
-        TODO write docstring.
-
         Parameters
         ----------
-        n_blocks
-        input_size
-        hidden_size
-        n_hidden
+        n_blocks : int
+            Number of MADE blocks.
+        input_size : int
+            Input dimensionality.
+        hidden_size : int
+            Hidden dimension in MADE.
+        n_hidden : int
+            Number of hidden layers in MADE.
         cond_label_size
-        activation
+        activation : str
+            Nonlinearity type.
         input_order
-        batch_norm
+        batch_norm : bool
+            Use batch normalization.
         kwargs
         """
+        
+        # TODO write docstring.
         super().__init__()
         # base distribution for calculation of log prob under the model
         self.register_buffer('base_dist_mean', torch.zeros(input_size))
@@ -542,7 +554,7 @@ class MAF(nn.Module):
         scale : float
             Scale parameter for prior.
         type : str
-            Type of prior to use. Options are ``"Laplce"`` and ``"Gaussian"``.
+            Type of prior to use. Options are ``"Laplace"`` and ``"Gaussian"``.
         Returns
         -------
         Log-prior of weights.
@@ -782,7 +794,7 @@ class RealNVP(nn.Module):
         scale : float
             Scale parameter for prior.
         type : str
-            Type of prior to use. Options are ``"Laplce"`` and ``"Gaussian"``.
+            Type of prior to use. Options are ``"Laplace"`` and ``"Gaussian"``.
         Returns
         -------
         Log-prior of weights.
